<?php
// SPDX-License-Identifier: EUPL-1.2
// Authors: see README.md

namespace SeaCMS\App;

use SeaCMS\App\TestException;
use Throwable;

/**
 * define exception to caught return for tests
 */
class TestBaseUrlException extends TestException
{
    /**
     * caught baseUrl
     * @var string
     */
    protected $baseUrl;

    /**
     * plugin dir
     * @var string
     */
    protected $pluginDir;

    /**
     * root dir
     * @var string
     */
    protected $rootDir;

    /**
     * theme dir
     * @var string
     */
    protected $themeDir;

    /**
     * currentPage
     * @var null|array
     */
    protected $currentPage;

    /**
     * twigVariables
     * @var null|array
     */
    protected $twigVariables;

    public function __construct(
        string $baseUrl,
        string $rootDir,
        string $pluginDir,
        string $themeDir,
        ?array $currentPage,
        ?array $twigVariables,
        string $message = "",
        int $code=0,
        Throwable $th = null
        )
    {
        parent::__construct($message,$code,$th);
        $this->baseUrl = $baseUrl;
        $this->rootDir = $rootDir;
        $this->pluginDir = $pluginDir;
        $this->themeDir = $themeDir;
        $this->currentPage = $currentPage;
        $this->twigVariables = $twigVariables;
    }

    /**
     * get baseUrl
     * @return string
     */
    public function getBaseUrl(): string
    {
        return $this->baseUrl;
    }

    /**
     * get pluginDir
     * @return string
     */
    public function getPluginDir(): string
    {
        return $this->pluginDir;
    }

    /**
     * get rootDir
     * @return string
     */
    public function getRootDir(): string
    {
        return $this->rootDir;
    }

    /**
     * get themeDir
     * @return string
     */
    public function getThemeDir(): string
    {
        return $this->themeDir;
    }

    /**
     * get currentPage
     * @return null|array
     */
    public function getcurrentPage(): ?array
    {
        return $this->currentPage;
    }

    /**
     * get twigVariables
     * @return null|array
     */
    public function getTwigVariables(): ?array
    {
        return $this->twigVariables;
    }

}
